gramex.apps.nlg package
=======================

Submodules
----------

gramex.apps.nlg.grammar module
------------------------------

.. automodule:: gramex.apps.nlg.grammar
    :members:
    :undoc-members:
    :show-inheritance:

gramex.apps.nlg.nlgapp module
-----------------------------

.. automodule:: gramex.apps.nlg.nlgapp
    :members:
    :undoc-members:
    :show-inheritance:

gramex.apps.nlg.nlgsearch module
--------------------------------

.. automodule:: gramex.apps.nlg.nlgsearch
    :members:
    :undoc-members:
    :show-inheritance:

gramex.apps.nlg.nlgutils module
-------------------------------

.. automodule:: gramex.apps.nlg.nlgutils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: gramex.apps.nlg
    :members:
    :undoc-members:
    :show-inheritance:
